@@ -107,7 +107,6 @@ class CSGenome(object):
         self.used_to_run = used_to_run.UsedToRunManager(self)
         self.benchmarks = benchmarks.BenchmarksManager(self)
         self.codename = codename.CodenameManager(self)
-        self.country = country.CountryManager(self)
         self.file_system = file_system.FileSystemManager(self)
         self.firmware = firmware.FirmwareManager(self)
         self.floating_point_unit = floating_point_unit.FloatingPointUnitManager(self)
@@ -322,12 +321,6 @@ class CSGenome(object):
             GitlabHttpError: When the return code is not 2xx
             GitlabParsingError: If the json data could not be parsed
         """
-
-        if "page" not in params.keys():
-            params['page'] = 1
-        if "limit" not in params.keys():
-            params['limit'] = 50
-
         res = CSGList(self, path, query_data=params).json()
         return (res['errors'], True) if 'errors' in res.keys() else (list(res['data']), False)
 
@@ -476,6 +469,10 @@ class CSGList(object):
 
     def gen(self, object_creator):
         # default the same query data with next page
+        if 'errors' in self._data:
+            from clientAPI.base import CSGError
+            raise CSGError(self._data)
+
         for item in self._data['data']:
             yield object_creator(item)
 
