@@ -67,7 +67,7 @@ class ListMixin(_RestManagerBase):
 
     def list(self, dictionary: Dict[str, Any] = None, columns: str | List[str] = None, exact=False,
              order_by: str | Order | List[str | Order] = None,
-             limit: int = None, **kwargs) -> List[base.RESTObject] | Dict:
+             limit: int = None, **kwargs) -> Tuple[List[base.RESTObject] | Dict, bool]:
         """
         Returns a list of all objects of the table.
         You can pass in a dictionary containing key value pairs to search and filter records by,
